@@ -1,8 +1,8 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 
-#        Copyright (C) 2009 Daniel Fett
-#         This program is free software: you can redistribute it and/or modify
+#   Copyright (C) 2010 Daniel Fett
+#   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
 #   the Free Software Foundation, either version 3 of the License, or
 #   (at your option) any later version.
@@ -15,12 +15,14 @@
 #   You should have received a copy of the GNU General Public License
 #   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-#        Author: Daniel Fett advancedcaching@fragcom.de
+#   Author: Daniel Fett agtl@danielfett.de
+#   Jabber: fett.daniel@jaber.ccc.de
+#   Bugtracker and GIT Repository: http://github.com/webhamster/advancedcaching
 #
 
 
-VERSION = 0
-VERSION_DATE = '2010-07-21'
+VERSION = 8
+VERSION_DATE = '2011-01-09'
 
 try:
     import json
@@ -228,6 +230,7 @@ class GeocachingComCacheDownloader(CacheDownloader):
 
     MAX_DOWNLOAD_NUM = 20
 
+    user_token = None
 
     CTIDS = {
         2:GeocacheCoordinate.TYPE_REGULAR,
@@ -253,31 +256,47 @@ class GeocachingComCacheDownloader(CacheDownloader):
 
 
     def _get_overview(self, location):
+        if self.user_token == None:
+            self._get_user_token()
         c1, c2 = location
-        url = 'http://www.geocaching.com/map/default.aspx?lat=49&lng=6'
-        values = {'eo_cb_id':'ctl00_ContentBody_cbAjax',
+        url = 'http://www.geocaching.com/map/default.aspx/MapAction?lat=9&lng=6'
+        '''values = {'eo_cb_id':'ctl00_ContentBody_cbAjax',
             'eo_cb_param':'{"c": 1, "m": "", "d": "%f|%f|%f|%f"}' % (max(c1.lat, c2.lat), min(c1.lat, c2.lat), max(c1.lon, c2.lon), min(c1.lon, c2.lon)),
             'eo_version':'5.0.51.2'
-        }
+        }'''
+        data = ('application/json', '{"dto":{"data":{"c":1,"m":"","d":"%f|%f|%f|%f"},"ut":"%s"}}' % (max(c1.lat, c2.lat), min(c1.lat, c2.lat), max(c1.lon, c2.lon), min(c1.lon, c2.lon), self.user_token))
 
         try:
-            response = self.downloader.get_reader(url, values)
+            response = self.downloader.get_reader(url, data = data)
             the_page = response.read()
 
-            extractor = re.compile('<ExtraData><!\[CDATA\[(.*)\]\]>', re.DOTALL)
-            match = extractor.search(the_page)
-            if match == None:
-                raise Exception('Could not load map of geocaches')
+            #extractor = re.compile('<ExtraData><!\[CDATA\[(.*)\]\]>', re.DOTALL)
+            #match = extractor.search(the_page)
+            #if match == None:
+            #    logger.debug(the_page)
+            #    raise Exception('Could not load map of geocaches')
         except Exception, e:
             CacheDownloader.lock.release()
             self.emit('download-error', e)
             return None
-        return match.group(1)
+        return the_page
+        
+    def _get_user_token(self):
+        page = self.downloader.get_reader('http://www.geocaching.com/map/default.aspx?lat=6&lng=9')
+        for line in page:
+            if line.startswith('var uvtoken'):
+                self.user_token = re.compile("userToken[ =]+'([^']+)'").search(line).group(1)
+                page.close()
+                return
+        raise Exception("Website contents unexpected. Please check connection.")
+        
 
     def _parse_overview(self, content, location, rec_depth = 0):
         c1, c2 = location
-        text = content.replace("\\'", "'")
-        a = json.loads(text.replace('\t', ' '))
+        #text = content.replace('\\"', '"')
+        #text = text.replace('\t', ' ')
+        full = json.loads(content)
+        a = json.loads(full['d'])
         points = []
         if not 'cc' in a['cs']:
             if 'count' in a['cs'] and 'count' != 0:
@@ -315,6 +334,7 @@ class GeocachingComCacheDownloader(CacheDownloader):
                 
     def _parse_cache_page(self, cache_page, coordinate):
         section = ''
+        prev_section = ''
         shortdesc = desc = hints = waypoints = images = logs = owner = head = ''
         logger.debug("Start parsing...")
         for line in cache_page:
@@ -343,8 +363,12 @@ class GeocachingComCacheDownloader(CacheDownloader):
             elif section == 'images' and line.startswith('<h3>'):
                 section = 'after-images'
             elif section == 'after-images' and line.startswith('<table class="LogsTable Table">'):
-                logs = line
-                break
+                section = 'logs'
+            
+
+            if section != prev_section:
+                logger.debug("Now in Section '%s', with line %s" % (section, line[:20:]))
+            prev_section = section
 
             if section == 'head':
                 head = "%s%s\n" % (head, line)
@@ -358,7 +382,11 @@ class GeocachingComCacheDownloader(CacheDownloader):
                 waypoints = "%s%s  " % (waypoints, line)
             elif section == 'images':
                 images = "%s%s " % (images, line)
-
+            elif section == 'logs':
+                logs = "%s%s" % (logs, line)
+                if line.endswith('</tr></table>'):
+                    break
+                
         logger.debug('finished parsing')
 
         coordinate.size, coordinate.difficulty, coordinate.terrain, coordinate.owner, coordinate.lat, coordinate.lon = self.__parse_head(head)
@@ -464,11 +492,12 @@ class GeocachingComCacheDownloader(CacheDownloader):
         output = []
         for l in lines:
             #lines = [re.sub("\w+", ' ', HTMLManipulations._decode_htmlentities(HTMLManipulations._strip_html(x, True)), '').sub('[ view this log ]') for x in lines[2:]]
-            m = re.match(r"""<td[^>]+><strong><img src="http://www\.geocaching\.com/images/icons/(?:icon_(?P<icon>[a-z]+)|(?P<icon2>coord_update))\.gif"[^>]*/>""" +
-                r"""&nbsp;(?P<month>[^ ]+) (?P<day>\d+)(, (?P<year>\d+))? by <a[^>]+>(?P<finder>[^<]+)</a></strong> \(\d+ found\)<br /><br />(?P<text>.+)""" +
-                r"""<br /><br /><small>""", l, re.DOTALL)
+            m = re.match(r"""<td[^>]+><strong><img src='http://www\.geocaching\.com/images/icons/(?:icon_(?P<icon>[a-z]+)|(?P<icon2>coord_update))\.gif'[^>]*/>""" +
+                r"""&nbsp;(?P<month>[^ ]+) (?P<day>\d+)(, (?P<year>\d+))? by <a[^>]+>(?P<finder>[^<]+)</a></strong>&nbsp;\(\d+ found\)<br ?/><br ?/>(?P<text>.+)""" +
+                r"""<br ?/><br ?/><small>""", l, re.DOTALL)
             if m == None:
                 #print "Could not parse Log-Line:\nBEGIN\n%s\nEND\n\n This can be normal." % l
+                logger.debug("Ignoring following log line:-----\n%s\n------" % l)
                 pass
             else:
                 type = m.group('icon') if m.group('icon') != None else m.group('icon2')
@@ -478,7 +507,7 @@ class GeocachingComCacheDownloader(CacheDownloader):
                 if year == '' or year == None:
                     year = datetime.datetime.now().year
                 finder = m.group('finder')
-                text = HTMLManipulations._strip_html(HTMLManipulations._replace_br(m.group('text')), True)
+                text = HTMLManipulations._decode_htmlentities(HTMLManipulations._strip_html(HTMLManipulations._replace_br(m.group('text')), True))
                 output.append(dict(type=type, month=month, day=day, year=year, finder=finder, text=text))
         return output
 
@@ -521,7 +550,7 @@ if __name__ == '__main__':
         a = GeocachingComCacheDownloader(downloader.FileDownloader('dummy', 'dummy', '/tmp/cookies'), '/tmp/', True)
     else: # cachedownloader.py username password
         name, password = sys.argv[1:3]
-        a = GeocachingComCacheDownloader(downloader.FileDownloader(name, password, '/tmp/cookies'), '/tmp/', True)
+        a = GeocachingComCacheDownloader(downloader.FileDownloader(name, password, '/tmp/cookies', GeocachingComCacheDownloader.login_callback(name, password)), '/tmp/', True)
 
         print "Using Username %s" % name
 
